package com.chelvc.framework.common.jackson;

import java.io.IOException;
import java.util.Map;

import com.chelvc.framework.common.util.ObjectUtils;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import com.google.common.collect.Maps;

/**
 * JSON枚举序列化处理器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class JacksonEnumerateSerializer extends StdSerializer<Object> {
    /**
     * 编号属性名称
     */
    public static final String CODE = "code";

    /**
     * 描述属性名称
     */
    public static final String DESCRIPTION = "description";

    public JacksonEnumerateSerializer() {
        super(Object.class);
    }

    @Override
    public void serialize(Object value, JsonGenerator generator, SerializerProvider provider) throws IOException {
        if (value instanceof Enum) {
            String name = ((Enum<?>) value).name();
            Map<String, Object> values = Maps.newHashMap(ObjectUtils.object2map(value));
            values.putIfAbsent(CODE, name);
            values.putIfAbsent(DESCRIPTION, name);
            generator.writeObject(values);
        } else {
            generator.writeObject(value);
        }
    }
}
